==> free-sa-1.2.4.tar.gz: free-sa-1.2.4/src/reports/r_usergraphs.c <==
#include "global.h"


void ReportGraphs(FILE *ifile, short int elcount, double *elarray) {
    short int i, j;
    double limits[] = {
                     1.0,
                   100.0,                    200.0,                    500.0,
                  1000.0,                   2000.0,                   5000.0,
             10.0*1024.0,              20.0*1024.0,              50.0*1024.0,
            100.0*1024.0,             200.0*1024.0,             500.0*1024.0,
           1024.0*1024.0,        2.0*1024.0*1024.0,        5.0*1024.0*1024.0,
      10.0*1024.0*1024.0,       20.0*1024.0*1024.0,       50.0*1024.0*1024.0,
     100.0*1024.0*1024.0,      200.0*1024.0*1024.0,      500.0*1024.0*1024.0,
    1024.0*1024.0*1024.0, 2.0*1024.0*1024.0*1024.0, 5.0*1024.0*1024.0*1024.0, 10.0*1024.0*1024.0*1024.0
    };


    for (i = sizeof(limits)/sizeof(double) - 1L; i != 0; i--) {
	fprintf(ifile, "<tr><th class=rt>%s", ShortBytes(limits[i]));
	for (j = 0; j < elcount; j++) {
	    if (elarray[j] >= limits[i]) {
		fprintf(ifile, "<td class=gr rowspan=%hd>%s", i, ShortBytes(elarray[j]));
		/* Use negative value for not printing it again */
		elarray[j] = -1;
	    }
	    else if (elarray[j] != -1) fprintf(ifile, "<td>");
	}
	fwrite("\n", 1L, 1L, ifile);
    }
    
    fprintf(ifile, "<tr><td class=el>");
    for (j = 0; j < elcount; j++) fprintf(ifile, "<th class=wh>%hd", j + 1);
}


void ReportUserGraphs(int i, double *mBytes) {
    FILE *UGR;


    UGR = SAfopenH("../", 'g', Users[i].vname, NULL, 1, "w", "%s/g_%s.html", icfg.ReportDir, Users[i].name);
    ReportGraphs(UGR, 31, mBytes);
    SAfcloseH(UGR, Users[i].fname);
}

==> free-sa-1.3.4.tar.gz: free-sa-1.3.4/src/reports/r_usergraphs.c <==
#include "global.h"


void ReportGraphs(FILE *ifile, short int elcount, double *elarray) {
    short int i, j;
    double limits[] = {
                     1.0,
                   100.0,                    200.0,                    500.0,
                  1000.0,                   2000.0,                   5000.0,
             10.0*1024.0,              20.0*1024.0,              50.0*1024.0,
            100.0*1024.0,             200.0*1024.0,             500.0*1024.0,
           1024.0*1024.0,        2.0*1024.0*1024.0,        5.0*1024.0*1024.0,
      10.0*1024.0*1024.0,       20.0*1024.0*1024.0,       50.0*1024.0*1024.0,
     100.0*1024.0*1024.0,      200.0*1024.0*1024.0,      500.0*1024.0*1024.0,
    1024.0*1024.0*1024.0, 2.0*1024.0*1024.0*1024.0, 5.0*1024.0*1024.0*1024.0, 10.0*1024.0*1024.0*1024.0
    };


    for (i = sizeof(limits)/sizeof(double) - 1L; i != 0; i--) {
	SAfprintf(ifile, "<tr><th class=rt>%s", SAB3(limits[i]));
	for (j = 0; j < elcount; j++) {
	    if (elarray[j] >= limits[i]) {
		SAfprintf(ifile, "<td class=gr rowspan=%hd>%s", i, SAB3(elarray[j]));
		/* Use negative value for not printing it again */
		elarray[j] = -1;
	    }
	    else if (elarray[j] != -1) SAfprintf(ifile, "<td>");
	}
	SAfwrite1("\n", 1L, ifile);
    }
    
    SAfprintf(ifile, "<tr><td class=el>");
    for (j = 0; j < elcount; j++) SAfprintf(ifile, "<th class=wh>%hd", j + 1);
}


void ReportAnyGraphs(double *mBytes, const char *vname, const char *name) {
    FILE *UGR;


    UGR = SAfopenH("../", 'g', vname, NULL, 1, "w", "%s/g_%s.html", icfg.ReportDir, name);
    ReportGraphs(UGR, 31, mBytes);
    SAfcloseH(UGR, name);
}
